{% extends "site_base.html" %}

{% load markitup_tags %}
{% load uni_form_tags %}

{% block body_class %}review{% endblock %}

{% block body %}
    <h1>Proposal Review</h1>
    
    <div class="proposal">
        <h2>{{ proposal.title }}</h2>
        
        <p>
            {% if proposal.cancelled %}
                Cancelled
            {% endif %}
        </p>
        
        <div>
            {{ proposal.description }}
        </div>
        
        <p><b>Type</b>: {{ proposal.get_session_type_display }}</p>
        
        <h3>Abstract</h3>
        <div class="abstract">
            {{ proposal.abstract_html|safe }}
        </div>
        
        <p><b>Audience level</b>: {{ proposal.get_audience_level_display }}</p>
        
        <p><b>Submitting speaker</b>: {{ proposal.speaker }}</p> {# @@@ bio? #}
        
        {% if proposal.additional_speakers.all %}
            <p><b>Additional speakers</b>:</p>
            <ul>
            {% for speaker in proposal.additional_speakers.all %}
                {% if speaker.user %}
                    <li><b>{{ speaker.name }}</b> &mdash; {{ speaker.email }}</li>
                {% else %}
                    <li>{{ speaker.email }} &mdash; pending invitation</li>
                {% endif %}
            {% endfor %}
            </ul>
        {% endif %}
        
        <h3>Additional Notes (private from submitter)</h3>
        <div class="additional_notes">
            {{ proposal.additional_notes }}
        </div>
    </div>
    
    {% markitup_media %}

    <h2>Review</h2>
    
    <form method="POST" action="{% url review_review proposal.pk %}" class="uniForm">
        {% csrf_token %}
        <fieldset class="inlineLabels">
            {{ review_form|as_uni_form }}
            <div class="form_block">
                <input type="submit" value="Submit" />
            </div>
        </fieldset>
    </form>
    
    <h2>Comment</h2>
    
    <form method="POST" action="{% url review_comment proposal.pk %}" class="uniForm">
        {% csrf_token %}
        <fieldset>
            {{ comment_form|as_uni_form }}
            <div class="form_block">
                <input type="submit" value="Submit" />
            </div>
        </fieldset>
    </form>
    
{% endblock %}
