{% load account_tags %}
<p>
    <b>{% user_display user %}</b> has made changes to <b>{{ proposal.title }}</b> which you have previously reviewed.
</p>
<p>
    {% url review_detail proposal.pk as detail_url %}
    View the latest version of the proposal online at <a href="http://{{ current_site }}{{ detail_url }}">http://{{ current_site }}{{ detail_url }}</a>
</p>