{% load sitetree %}
<ul class="dropdown-menu">
    {% for item in sitetree_items %}
    <li>
        <a href="{% sitetree_url for item %}" title="{{ item.hint|default:"" }}">{{ item.title_resolved }}</a>
    </li>
    {% endfor %}
</ul>
