{% load i18n account_tags %}
{% user_display user as username %}
{% blocktrans with team_name=team team_url=team.get_absolute_url site_name=current_site.name site_url=current_site %}
    <p>
        User "{{ username }}" has applied to join <b>{{ team_name }}</b> on {{ site_name }}.
    </p>

    <p>
        To accept this application and see any other pending applications, visit the following url:
        <a href="http://{{ site_url }}{{ team_url }}">http://{{ site_url }}{{ team_url }}</a>
    </p>
{% endblocktrans %}
