<p>{{ proposal.speaker.name }} attached you as an additional speaker to a
    talk proposal for {{ current_site.name }} entitled "{{ proposal.title }}".</p>

<p>Go to</p>

<p><a href="http://{{ current_site }}{% url speaker_create_token token %}">http://{{ current_site }}{% url speaker_create_token token %}</a></p>

<p>to confirm.</p>

<p>If you don't have account on the website, you will be asked to create one.</p>
