{% extends "site_base.html" %}

{% load i18n %}
{% load sitetree %}

{% block head_title %}User List{% endblock %}

{% block extra_style %}
    <style type="text/css">
        div.dataTables_length label {
            float: left;
            text-align: left;
        }

        div.dataTables_length select {
            width: 75px;
        }

        div.dataTables_filter label {
            float: right;
        }

        div.dataTables_info {
            padding-top: 8px;
        }

        div.dataTables_paginate {
            float: right;
            margin: 0;
        }

        table.table {
            clear: both;
            margin-bottom: 6px !important;
            background-color: white;
        }

        table.table thead .sorting,
        table.table thead .sorting_asc,
        table.table thead .sorting_desc,
        table.table thead .sorting_asc_disabled,
        table.table thead .sorting_desc_disabled {
            cursor: pointer;
            *cursor: hand;
        }

        table.dataTable th:active {
            outline: none;
        }
    </style>
{% endblock %}

{% block body_outer %}
    <div class="row">
        <div class="span12">
            <h1>User List</h1>
            <table class="table table-striped table-bordered table-reviews">
                <thead>
                    <th>{% trans "Email" %}</th>
                    <th>{% trans "Name" %}</th>
                    <th>{% trans "Speaker Profile?" %}</th>
                </thead>
                
                <tbody>
                    {% for user in users %}
                        <tr>
                            <td>{{ user.email }}</td>
                            <td>{{ user.get_full_name }}</td>
                            <td>
                                {% if user.speaker_profile %}
                                    <a href="{% url speaker_profile user.speaker_profile.pk %}">{{ user.speaker_profile }}</a>
                                {% else %}
                                    <a href="{% url speaker_create_staff user.pk %}" class="btn btn-mini">create</a>
                                {% endif %}
                            </td>
                        </tr>
                    {% endfor %}
                </tbody>
            </table>
        </div>
    </div>
{% endblock %}

{% block extra_script %}
    <script src="{{ STATIC_URL }}datatables/js/jquery.dataTables.min.js" type="text/javascript"></script>
    <script src="{{ STATIC_URL }}tabletools/js/TableTools.min.js" type="text/javascript"></script>
    <script src="{{ STATIC_URL }}datatables/js/dataTables.bootstrap.js" type="text/javascript"></script>
    <script type="text/javascript">
        $(function() {
            $(".tip").tooltip();
            $("table.table-reviews").dataTable({
                "sDom": "<'row'<'span3'l><'span3'T><'span4'f>r>t<'row'<'span3'i><'span5'p>>",
                "sPaginationType": "bootstrap",
                "bStateSave": true,
                "oTableTools": {
                    "aButtons": [
                        "copy",
                        "csv",
                        "print"
                    ],
                    "sSwfPath": "{{ STATIC_URL }}tabletools/swf/copy_csv_xls.swf"
                }
            });
        });
    </script>
{% endblock %}
