{% load sitetree %}
<ul class="nav">
    {% for item in sitetree_items %}
    <li class="{{ item.is_current|yesno:"active ," }}{% if item.has_children %}dropdown{% endif %}">
        {% if item.has_children %}
            <a href="#" class="dropdown-toggle" data-toggle="dropdown" title="{{ item.hint|default:"" }}">
                {{ item.title_resolved }}
                <b class="caret"></b>
            </a>
            {% sitetree_children of item for menu template "sitetree/submenu.html" %}
        {% else %}
            <a href="{% sitetree_url for item %}" title="{{ item.hint|default:"" }}">{{ item.title_resolved }}</a>
        {% endif %}
    </li>
    {% endfor %}
</ul>
